aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/hypixelCached.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/hypixelCached.ts b/src/hypixelCached.ts
index d9e718e..aab5407 100644
--- a/src/hypixelCached.ts
+++ b/src/hypixelCached.ts
@@ -34,10 +34,10 @@ export const playerCache = new NodeCache({
useClones: true,
})
// cache "basic players" (players without profiles) for 4 hours
export const basicPlayerCache: LRUCache<string, CleanPlayer> = new LRUCache({
max: 20000,
- maxAge: 60 * 60 * 4 * 1000,
+ maxAge: 60 * 30,
})
export const profileCache = new NodeCache({
@@ -34,10 +34,10 @@ export const playerCache = new NodeCache({
useClones: true,
})
-// cache "basic players" (players without profiles) for 4 hours
+// cache "basic players" (players without profiles) for 30 minutes
export const basicPlayerCache: LRUCache<string, CleanPlayer> = new LRUCache({
max: 20000,